@@ -20,10 +20,10 @@
 #'              As a convenience, \code{edsurvey.data.frame}
 #'              implements the \code{$} function to extract a variable.
 #'
-#' @param data an \code{edsurvey.data.frame} 
+#' @param data an \code{edsurvey.data.frame}
 #' @param userConditions a list of user conditions that includes subsetting or recoding conditions
 #' @param defaultConditions a list of default conditions that often are set for each survey
-#' @param dataList a list of \code{dataListItem} objects to model the data structure of the survey 
+#' @param dataList a list of \code{dataListItem} objects to model the data structure of the survey
 #' @param weights a list that stores information regarding weight variables. See Details.
 #' @param pvvars a list that stores information regarding plausible values. See Details.
 #' @param subject a character that indicates the subject domain of the given data
@@ -75,12 +75,12 @@
 #' The \code{pvvars} list has an element for each subject or subscale score
 #' that has plausible values. Each element is a list with a \code{varnames}
 #' element that indicates the column names of the plausible values and an
-#' \code{achievementLevel} argument that is a named vector of the 
+#' \code{achievementLevel} argument that is a named vector of the
 #' achievement-level cutpoints.
-#' 
+#'
 #' An \code{edsurvey.data.frame} implements a unique data caching mechanism that allows users to create and merge data columns for flexibility.
 #' This \code{cache} object is a single \code{data.frame} that is an element in the \code{edsurvey.data.frame}. To accommodate studies with complex data models
-#' the cache can only support one data level at this time. The \code{cacheDataLevelName} parameter indicates which named element in the \code{dataList} 
+#' the cache can only support one data level at this time. The \code{cacheDataLevelName} parameter indicates which named element in the \code{dataList}
 #' the cache is indicated. The default value \code{cacheDataLevelName = NULL} will set the first item in the \code{dataList} as the \code{cache} level for an \code{edsurvey.data.frame}.
 #'
 #'
@@ -152,10 +152,10 @@
 #' \emph{Extracting and updating attributes of an object of class \code{edsurvey.data.frame} or \code{light.edsurvey.data.frame}}
 #'
 #' Users can use the \code{getAttributes} method to extract any attribute of
-#' an \code{edsurvey.data.frame} or a \code{light.edsurvey.data.frame}. 
+#' an \code{edsurvey.data.frame} or a \code{light.edsurvey.data.frame}.
 #' The \code{errorCheck} parameter has a default value of\code{TRUE}, which throws an error if an attribute is not found.
 #' Setting \code{errorCheck = FALSE} will suppress error checking, and return \code{NULL} if an attribute can't be found.
-#' 
+#'
 #' A \code{light.edsurvey.data.frame} will not have attributes related to data connection
 #' because data have already been read in memory.
 #'
@@ -171,7 +171,7 @@
 #' @export
 edsurvey.data.frame <- function(userConditions,
                                 defaultConditions,
-                                dataList=list(),
+                                dataList = list(),
                                 weights,
                                 pvvars,
                                 subject,
@@ -186,143 +186,148 @@ edsurvey.data.frame <- function(userConditions,
                                 psuVar,
                                 stratumVar,
                                 jkSumMultiplier,
-                                recodes=NULL,
-                                validateFactorLabels=FALSE,
-                                forceLower=TRUE,
-                                reqDecimalConversion=TRUE,
-                                fr2Path=NULL,
-                                dim0=NULL,
-                                cacheDataLevelName=NULL) {
-  
+                                recodes = NULL,
+                                validateFactorLabels = FALSE,
+                                forceLower = TRUE,
+                                reqDecimalConversion = TRUE,
+                                fr2Path = NULL,
+                                dim0 = NULL,
+                                cacheDataLevelName = NULL) {
   if (is.list(achievementLevels)) {
     achievementLevels <- lapply(achievementLevels, function(l) {
       sort(l)
     })
   } else {
     # In the international assessment TALIS, there is no achievement level, account for that here
-    if(!is.null(achievementLevels)) {
+    if (!is.null(achievementLevels)) {
       achievementLevels <- sort(achievementLevels)
       # names can't be missing, but they can be length 0. Figure out if that is the case.
-      if(min(nchar(names(achievementLevels)))==0) {
+      if (min(nchar(names(achievementLevels))) == 0) {
         stop(paste0("The argument ", sQuote("achievementLevels"), " must have nonmissing names for each level."))
       }
       for (pvi in seq_along(pvvars)) {
         # setup achievement levels for all plausible value variables
-        temp = list(varnames = pvvars[[pvi]]$varnames)
+        temp <- list(varnames = pvvars[[pvi]]$varnames)
         temp$achievementLevel <- achievementLevels
         pvvars[[names(pvvars)[pvi]]] <- temp
       }
     }
-  } #closes else statment following if (is.list(achievementLevels))
-  
-  hasDim0 <- all(is.numeric(dim0)) #logical to indicate if dim0 was user provided in constructor
-  if(!hasDim0){
-    dim0 <- c(0,0) #temporary holder until we create the edsurvey.data.frame, then we will update it
+  } # closes else statment following if (is.list(achievementLevels))
+
+  hasDim0 <- all(is.numeric(dim0)) # logical to indicate if dim0 was user provided in constructor
+  if (!hasDim0) {
+    dim0 <- c(0, 0) # temporary holder until we create the edsurvey.data.frame, then we will update it
   }
-  
-  if(is.null(cacheDataLevelName)){
-    cacheDataLevelName <- names(dataList)[1] #use first dataListItem level if not specified as default
+
+  if (is.null(cacheDataLevelName)) {
+    cacheDataLevelName <- names(dataList)[1] # use first dataListItem level if not specified as default
   }
-  
-  if(forceLower) {
+
+  if (forceLower) {
     i <- 1
-    for(dl in dataList){
+    for (dl in dataList) {
       names(dl$lafObject) <- tolower(names(dl$lafObject))
       dl$fileFormat$variableName <- tolower(dl$fileFormat$variableName)
       dl$mergeVars <- tolower(dl$mergeVars)
       dl$parentMergeVars <- tolower(dl$parentMergeVars)
-      
+
       dataList[[i]] <- dl
       i <- i + 1
     }
   }
-  
-  res <- list(userConditions=userConditions,
-              defaultConditions=defaultConditions,
-              dataList=dataList,
-              weights=weights,
-              pvvars=pvvars,
-              subject=subject,
-              year=year,
-              assessmentCode=assessmentCode,
-              dataType=dataType,
-              gradeLevel=gradeLevel,
-              achievementLevels=achievementLevels,
-              omittedLevels=omittedLevels,
-              survey=survey,
-              country=country,
-              psuVar=psuVar,
-              stratumVar=stratumVar,
-              jkSumMultiplier=jkSumMultiplier,
-              recodes=recodes,
-              dim0=dim0, #update after it's reclassed to an edsurvey.data.frame (if not user supplied)
-              validateFactorLabels=validateFactorLabels,
-              cacheDataLevelName=cacheDataLevelName,
-              reqDecimalConversion=reqDecimalConversion,
-              fr2Path=fr2Path,
-              dichotParamTab=NULL, #IRT Param
-              polyParamTab=NULL, #IRT Param
-              adjustedData=NULL, #IRT Param
-              testData=NULL, #IRT Param
-              scoreCard=NULL, #IRT Param
-              scoreDict=NULL, #IRT Param
-              scoreFunction=NULL #IRT scoring
-              )
-  
+
+  res <- list(
+    userConditions = userConditions,
+    defaultConditions = defaultConditions,
+    dataList = dataList,
+    weights = weights,
+    pvvars = pvvars,
+    subject = subject,
+    year = year,
+    assessmentCode = assessmentCode,
+    dataType = dataType,
+    gradeLevel = gradeLevel,
+    achievementLevels = achievementLevels,
+    omittedLevels = omittedLevels,
+    survey = survey,
+    country = country,
+    psuVar = psuVar,
+    stratumVar = stratumVar,
+    jkSumMultiplier = jkSumMultiplier,
+    recodes = recodes,
+    dim0 = dim0, # update after it's reclassed to an edsurvey.data.frame (if not user supplied)
+    validateFactorLabels = validateFactorLabels,
+    cacheDataLevelName = cacheDataLevelName,
+    reqDecimalConversion = reqDecimalConversion,
+    fr2Path = fr2Path,
+    dichotParamTab = NULL, # IRT Param
+    polyParamTab = NULL, # IRT Param
+    adjustedData = NULL, # IRT Param
+    testData = NULL, # IRT Param
+    scoreCard = NULL, # IRT Param
+    scoreDict = NULL, # IRT Param
+    scoreFunction = NULL # IRT scoring
+  )
+  if (is.null(res$year)) {
+    res$year <- NA
+  }
   # form cache, first grab dim
   ROWID <- 1
   # make cache
-  res$cache <- data.frame(ROWID=ROWID)
+  res$cache <- data.frame(ROWID = ROWID)
   class(res) <- c("edsurvey.data.frame", "edsurvey.data")
-  
-  
-  if(is.null(defaultConditions) || is.na(defaultConditions)){
-    cache <- data.frame(ROWID=1:(dataList[[cacheDataLevelName]]$nrow),
-                        DEFAULT=TRUE)
-  } else { #default conditions are supplied, calculate them here
+
+  if (is.null(defaultConditions) || is.na(defaultConditions)) {
+    cache <- data.frame(
+      ROWID = 1:(dataList[[cacheDataLevelName]]$nrow),
+      DEFAULT = TRUE
+    )
+  } else { # default conditions are supplied, calculate them here
     # use getData on this, as of yet incomplete edsurvey.data.frame
     # to get row IDs
     # supressWarnings because it is just about nrow
     checkDL <- dataList[[cacheDataLevelName]]
     checkVar <- checkDL$fileFormat$variableName[!(checkDL$fileFormat$variableName %in% checkDL$ignoreVars)][1]
-    suppressWarnings(gd0 <- getData(res, varnames=checkVar, dropUnusedLevels=FALSE, omittedLevels=FALSE, defaultConditions=FALSE))
-    suppressWarnings(gd <- getData(res, varnames=checkVar, dropUnusedLevels=FALSE, omittedLevels=FALSE))
+    suppressWarnings(gd0 <- getData(res, varnames = checkVar, dropUnusedLevels = FALSE, dropOmittedLevels = FALSE, defaultConditions = FALSE))
+    suppressWarnings(gd <- getData(res, varnames = checkVar, dropUnusedLevels = FALSE, dropOmittedLevels = FALSE))
     class(res) <- "list"
-    cache <- data.frame(ROWID=1:nrow(gd0),
-                        DEFAULT=1:nrow(gd0) %in% rownames(gd))
+    cache <- data.frame(
+      ROWID = 1:nrow(gd0),
+      DEFAULT = 1:nrow(gd0) %in% rownames(gd)
+    )
   }
 
   # change back to a list to allow assignment of the cache
   res$cache <- cache
   # return to edsurvey.data.frame
   class(res) <- c("edsurvey.data.frame", "edsurvey.data")
-  
-  if(hasDim0){
+
+  if (hasDim0) {
     res$dim0 <- dim0
-  }else{  
+  } else {
     res$dim0 <- c(nrow(res), length(colnames(res)))
   }
-  
+
   # we discovered that not closing a LaF connections leads to memory leaks.
   # so, close all of the connections when it is complete (constructed).
-  for(item in dataList){
+  for (item in dataList) {
     LaF::close(item$lafObject)
   }
-  #check PSU/Stratum variables to see if 1) they are specified; if so, 2) they are defined in the data variables
+  # check PSU/Stratum variables to see if 1) they are specified; if so, 2) they are defined in the data variables
   checkPS <- TRUE
-  if(is.null(psuVar) || is.null(stratumVar)){
-    if(!all(c("psuVar", "stratumVar") %in% unlist(lapply(weights, names)))) {
+  if (is.null(psuVar) || is.null(stratumVar)) {
+    if (!all(c("psuVar", "stratumVar") %in% unlist(lapply(weights, names)))) {
       warning("PSU or Stratum variable(s) are undefined for this data. Taylor series variance estimation will not be possible.")
     }
     checkPS <- FALSE
   }
-  if(checkPS){
+  if (checkPS) {
     # if the sampling method is not stratified (and so is JK1) then there are not PSU and stratum variables.
-    if(any(!c(psuVar, stratumVar) %in% c("JK1", colnames(res)))) {
+    if (any(!c(psuVar, stratumVar) %in% c("JK1", colnames(res)))) {
       warning("Cannot find both PSU and Stratum variables on data. Taylor series variance estimation will not be possible.")
     }
   }
-  
+
   return(res)
 }
 
@@ -334,23 +339,27 @@ edsurvey.data.frame <- function(userConditions,
   if (i %in% names(x)) {
     return(x[[i]])
   }
-  
-  success <- tryCatch({z <- getData(x, varnames=i,dropUnusedLevels=FALSE, omittedLevels=FALSE, drop=TRUE, returnJKreplicates=FALSE)
-                        TRUE
-                      },error = function(e){
-                        warning(paste0("No object or data variable found named ", sQuote(i)))
-                        FALSE
-                      })
-                  
-  if(success){
+
+  success <- tryCatch(
+    {
+      z <- getData(x, varnames = i, dropUnusedLevels = FALSE, dropOmittedLevels = FALSE, drop = TRUE, returnJKreplicates = FALSE)
+      TRUE
+    },
+    error = function(e) {
+      warning(paste0("No object or data variable found named ", sQuote(i)))
+      FALSE
+    }
+  )
+
+  if (success) {
     return(z)
-  }else{
+  } else {
     return(invisible(NULL))
   }
 }
 
 # @note The \code{dataListItem} function is a useful constructor for building the individual \code{dataList} heirarchy data model components of each \code{dataList} object of an \code{edsurvey.data.frame}.
-#        It's recommended to always use this constructor, as it applies default values, calculations, validation checks, and to help for future functionality.  
+#        It's recommended to always use this constructor, as it applies default values, calculations, validation checks, and to help for future functionality.
 # @param lafObject an LaF object file that stores the data file connection and information.
 # @param fileFormat a data.frame of the defined file format specifications of the data file.  See \code{edsurvey.data.frame} Details.
 # @param levelLabel a character to describe the name of this \code{dataListItem}.  Must be unique from other \code{dataListItem} objects in the same \code{edsurvey.data.frame}.
@@ -378,30 +387,31 @@ dataListItem <- function(lafObject,
                          ignoreVars = NULL,
                          isDimLevel = FALSE,
                          conflictLevels = NULL) {
-
-  if(!inherits(lafObject,"laf")){
+  if (!inherits(lafObject, "laf")) {
     stop(paste0("The ", dQuote("lafObject"), " must be a LaF object utilizing the LaF Package."))
   }
 
-  if (length(parentMergeLevels)!=length(parentMergeVars)){
+  if (length(parentMergeLevels) != length(parentMergeVars)) {
     stop(paste0("The lengths of ", dQuote("parentMergeLevels"), " and ", dQuote("parentMergeVars"), " must be equal."))
   }
 
-  if (length(parentMergeVars)!=length(mergeVars)){
+  if (length(parentMergeVars) != length(mergeVars)) {
     stop(paste0("The lengths of ", dQuote("parentMergeVars"), " and ", dQuote("mergeVars"), " must be equal."))
   }
-  
-  res <- list(lafObject = lafObject,
-              fileFormat = fileFormat,
-              levelLabel = levelLabel,
-              forceMerge = forceMerge,
-              parentMergeLevels = parentMergeLevels,
-              parentMergeVars = parentMergeVars,
-              mergeVars = mergeVars,
-              ignoreVars = ignoreVars,
-              isDimLevel = isDimLevel,
-              conflictLevels = conflictLevels,
-              nrow = nrow(lafObject))
+
+  res <- list(
+    lafObject = lafObject,
+    fileFormat = fileFormat,
+    levelLabel = levelLabel,
+    forceMerge = forceMerge,
+    parentMergeLevels = parentMergeLevels,
+    parentMergeVars = parentMergeVars,
+    mergeVars = mergeVars,
+    ignoreVars = ignoreVars,
+    isDimLevel = isDimLevel,
+    conflictLevels = conflictLevels,
+    nrow = nrow(lafObject)
+  )
 
   return(res)
 }
@@ -435,13 +445,13 @@ dataListItem <- function(lafObject,
 #' @return an object of the same class as \code{x}
 #' @references
 #' Wickham, H. (2014). \emph{Advanced R}. Boca Raton, FL: Chapman & Hall/CRC.
-#' 
+#'
 #' @author Paul Bailey and Trang Nguyen
 #' @example man\examples\subset.edsurvey.data.frame.R
 #' @method subset edsurvey.data.frame
 #' @export
-subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
-  if(!inherits(x, c("edsurvey.data.frame"))) {
+subset.edsurvey.data.frame <- function(x, subset, ..., inside = FALSE) {
+  if (!inherits(x, c("edsurvey.data.frame"))) {
     stop(paste0("The argument ", sQuote("x"), " must be an edsurvey.data.frame."))
   }
 
@@ -452,32 +462,36 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
   # when they called subset and the condition will not change as that
   # variable is updated.
   # add it to the user conditions
-  if(inside) {
-    if(inherits(subset, "character")) {
-      subset <- parse(text=subset)[[1]]
+  if (inside) {
+    if (inherits(subset, "name")) {
+      subset <- eval(subset)
+    }
+    if (inherits(subset, "character")) {
+      subset <- parse(text = subset)[[1]]
     }
     condition_call <- subset
   } else {
     # substitute in variables that are available in the current subsetEnvironment
-    condition_call <- iparse(substitute(subset), x=x)
-  } # Enf of if esle statmet: if imside is true 
+    condition_call <- iparse(substitute(subset), x = x)
+  } # Enf of if esle statmet: if imside is true
   # apply filter
-  if(!all(all.vars(substitute(condition_call)) %in% colnames(x))) {
-    condition_call <- iparse(condition_call, x=x)
+  if (!all(all.vars(substitute(condition_call)) %in% colnames(x))) {
+    condition_call <- iparse(condition_call, x = x)
   }
   x[["userConditions"]] <- c(x[["userConditions"]], list(condition_call))
   # test filter
-  gg <- tryCatch(getData(x, c("ROWID", colnames(x)[1]), returnJKreplicates=FALSE),
-           error=function(e) {
-             subsetVars <- all.vars(condition_call)
-             for (v in subsetVars) {
-               if (!v %in% colnames(x)) {
-                 stop("Required variable ", sQuote(v), " is not found in the incoming data or on the environment.")
-               }
-             }
-           },
-           warning=function(w) {} )
-  x$cache$DEFAULT <- ifelse( x$cache$ROWID %in% gg$ROWID, TRUE, FALSE)
+  gg <- tryCatch(getData(x, c("ROWID", colnames(x)[1]), returnJKreplicates = FALSE),
+    error = function(e) {
+      subsetVars <- all.vars(condition_call)
+      for (v in subsetVars) {
+        if (!v %in% colnames(x)) {
+          stop("Required variable ", sQuote(v), " is not found in the incoming data or on the environment.")
+        }
+      }
+    },
+    warning = function(w) {}
+  )
+  x$cache$DEFAULT <- ifelse(x$cache$ROWID %in% gg$ROWID, TRUE, FALSE)
   x
 } # end of fuction subset.edsurvey.data.frame
 
@@ -485,20 +499,22 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 #' @export
 "[[.edsurvey.data.frame" <- function(x, i, j, ...) {
   # check for $ calls to list elements
-  if(length(i) == 1) {
-    if(i %in% names(x)) {
+  if (length(i) == 1) {
+    if (i %in% names(x)) {
       class(x) <- "list"
       return(x[[i]])
     }
   }
-  if(is.numeric(i)) {
+  if (is.numeric(i)) {
     i <- colnames(x)[i]
   }
   suppressWarnings(
-    z <- getData(x, varnames=i,
-                 dropUnusedLevels=FALSE, omittedLevels=FALSE,
-                 addAttributes=TRUE, returnJKreplicates=FALSE)
+    z <- getData(x,
+      varnames = i,
+      dropUnusedLevels = FALSE, dropOmittedLevels = FALSE,
+      addAttributes = TRUE, returnJKreplicates = FALSE
     )
+  )
   z[j, ]
 }
 
@@ -506,41 +522,41 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 #' @export
 "[<-.edsurvey.data.frame" <- function(x, i, j, ..., value) {
   value <- eval(value)
-  if(!missing(i)) {
+  if (!missing(i)) {
     i <- eval(i)
   }
-  if(missing(j)) {
+  if (missing(j)) {
     stop("Assignmeht by row is not allowed on an edsurvey.data.frame. Try assigning a single column at a time.")
   }
   j <- eval(j)
-  if(is.numeric(j)) {
+  if (is.numeric(j)) {
     name <- colnames(x)[j]
   } else {
     name <- j
   }
-  
-  if(name %in% c("ROWID", "DEFAULT")) {
+
+  if (name %in% c("ROWID", "DEFAULT")) {
     stop("Colum names must not be reserved words (ROWID or DEFAULT).")
   }
   cl0 <- class(x)
   class(x) <- "list"
-  if(is.null(value)) {
-    x$cache[i , name] <- NULL
+  if (is.null(value)) {
+    x$cache[i, name] <- NULL
     class(x) <- cl0
     return(invisible(x))
   }
   # because of "mySDF$name[subset] <-" it is possible for a new factor to be valid
   # but for the below assignment to appear invalid, this clears the cache and
   # overwrite, which always works
-  if(name %in% colnames(x$cache) && inherits(x$cache[,name], "factor")) {
+  if (name %in% colnames(x$cache) && inherits(x$cache[ , name], "factor")) {
     x$cache[ , name] <- NULL
   }
   # cannot subset assign non-primative lfactors, so do not try
-  if(inherits(value, "lfactor")) {
+  if (inherits(value, "lfactor")) {
     value <- as.factor(value)
   }
-  if(!missing(i)) {
-    if(name %in% colnames(x$cache)) {
+  if (!missing(i)) {
+    if (name %in% colnames(x$cache)) {
       # name already on the cache, we can directly assign a subset
       x$cache[x$cache$DEFAULT, name][i] <- value
     } else {
@@ -559,23 +575,25 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 #' @export
 "[.edsurvey.data.frame" <- function(x, i, j, ...) {
   # check for $ calls to list elements
-  if(missing(j)) {
+  if (missing(j)) {
     j <- colnames(x)
   }
-  if(length(j) == 1) {
-    if(j %in% names(x)) {
+  if (length(j) == 1) {
+    if (j %in% names(x)) {
       class(x) <- "list"
       return(x[[j]])
     }
   }
-  if(is.numeric(j)) {
+  if (is.numeric(j)) {
     j <- colnames(x)[j]
   }
   suppressWarnings(
-    z <- getData(x, varnames=j,
-                 dropUnusedLevels=FALSE, omittedLevels=FALSE,
-                 addAttributes=TRUE, returnJKreplicates=FALSE)
+    z <- getData(x,
+      varnames = j,
+      dropUnusedLevels = FALSE, dropOmittedLevels = FALSE,
+      addAttributes = TRUE, returnJKreplicates = FALSE
     )
+  )
   z[i, ]
 }
 
@@ -586,19 +604,19 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 "$<-.edsurvey.data.frame" <- function(x, name, value) {
   cl <- match.call()
   cl2 <- cl
-  if(name %in% names(x)) {
+  if (name %in% names(x)) {
     cl0 <- class(x)
     class(x) <- "list"
     x[[name]] <- value
     class(x) <- cl0
     invisible(x)
   } else {
-    if(name %in% c("ROWID", "DEFAULT")) {
+    if (name %in% c("ROWID", "DEFAULT")) {
       stop("Colum names must not be reserved words (ROWID or DEFAULT).")
     }
     cl0 <- class(x)
     class(x) <- "list"
-    if(is.null(value)) {
+    if (is.null(value)) {
       x$cache[ , name] <- NULL
       class(x) <- cl0
       return(invisible(x))
@@ -606,11 +624,11 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
     # because of "mySDF$name[subset] <-" it is possible for a new factor to be valid
     # but for the below assignment to appear invalid, this clears the cache and
     # overwrite, which always works
-    if(name %in% colnames(x$cache) && inherits(x$cache[,name], "factor")) {
+    if (name %in% colnames(x$cache) && inherits(x$cache[ , name], "factor")) {
       x$cache[ , name] <- NULL
     }
     # cannot subset assign non-primative lfactors, so do not try
-    if(inherits(value, "lfactor")) {
+    if (inherits(value, "lfactor")) {
       value <- as.factor(value)
     }
     x$cache[x$cache$DEFAULT, name] <- value
@@ -623,23 +641,23 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 #' @method + edsurvey.data
 #' @export
 "+.edsurvey.data" <- function(e1, e2) {
-  if(inherits(e1, "edsurvey.data.frame") & inherits(e2, "edsurvey.data.frame")) {
+  if (inherits(e1, "edsurvey.data.frame") & inherits(e2, "edsurvey.data.frame")) {
     return(edsurvey.data.frame.list(list(e1, e2)))
   } else {
-    if( (inherits(e1, "edsurvey.data.frame.list") & inherits(e2, "edsurvey.data.frame.list"))) {
+    if ((inherits(e1, "edsurvey.data.frame.list") & inherits(e2, "edsurvey.data.frame.list"))) {
       datalist <- c(e1$datalist, e2$datalist)
       return(edsurvey.data.frame.list(datalist))
     }
-    if( (inherits(e1, "edsurvey.data.frame") | inherits(e1, "edsurvey.data.frame.list")) &
-        (inherits(e2, "edsurvey.data.frame") | inherits(e2, "edsurvey.data.frame.list")) ) {
-        datalist <- list()
-        if(inherits(e1, "edsurvey.data.frame.list")) {
-          datalist <- c(e1$datalist, list(e2))
-        }
-        if(inherits(e2, "edsurvey.data.frame.list")) {
-          datalist <- c(list(e1), e2$datalist)
-        }
-        return(edsurvey.data.frame.list(datalist))
+    if ((inherits(e1, "edsurvey.data.frame") | inherits(e1, "edsurvey.data.frame.list")) &
+      (inherits(e2, "edsurvey.data.frame") | inherits(e2, "edsurvey.data.frame.list"))) {
+      datalist <- list()
+      if (inherits(e1, "edsurvey.data.frame.list")) {
+        datalist <- c(e1$datalist, list(e2))
+      }
+      if (inherits(e2, "edsurvey.data.frame.list")) {
+        datalist <- c(list(e1), e2$datalist)
+      }
+      return(edsurvey.data.frame.list(datalist))
     } else {
       stop(paste0(dQuote(.Generic), " not defined for ", pasteItems(dQuote(class(e1))), " and ", pasteItems(dQuote(class(e2)))))
     }
@@ -655,29 +673,37 @@ subset.edsurvey.data.frame <- function(x, subset, ..., inside=FALSE) {
 #' @method != edsurvey.data
 #' @export
 "!=.edsurvey.data" <- function(e1, e2) {
-  equals.edsurvey.data(e1, e2, notFunction = function(x) { return(!x) })
+  equals.edsurvey.data(e1, e2, notFunction = function(x) {
+    return(!x)
+  })
 }
 
 equals.edsurvey.data <- function(e1, e2, notFunction) {
-  if(inherits(e1, "edsurvey.data.frame") & inherits(e2, "edsurvey.data.frame")) {
+  if (inherits(e1, "edsurvey.data.frame") & inherits(e2, "edsurvey.data.frame")) {
     return(notFunction(sameSurvey(e1, e2)))
   }
-  if(inherits(e1, "edsurvey.data.frame.list") & inherits(e2, "edsurvey.data.frame.list")) {
+  if (inherits(e1, "edsurvey.data.frame.list") & inherits(e2, "edsurvey.data.frame.list")) {
     d1 <- e1$datalist
     d2 <- e2$datalist
-    if(length(d1) != length(d2) & min(c(length(d1), length(d2))) != 1) {
+    if (length(d1) != length(d2) & min(c(length(d1), length(d2))) != 1) {
       stop("Objects do not have the same number of elements in them.")
     }
-    return(notFunction(unlist(lapply(1:length(d1) , function(x) { sameSurvey(d1[[x]], d2[[x]]) }))))
+    return(notFunction(unlist(lapply(1:length(d1), function(x) {
+      sameSurvey(d1[[x]], d2[[x]])
+    }))))
   }
-  if( (inherits(e1, "edsurvey.data.frame") | inherits(e1, "edsurvey.data.frame.list")) &
-      (inherits(e2, "edsurvey.data.frame") | inherits(e2, "edsurvey.data.frame.list")) ) {
+  if ((inherits(e1, "edsurvey.data.frame") | inherits(e1, "edsurvey.data.frame.list")) &
+    (inherits(e2, "edsurvey.data.frame") | inherits(e2, "edsurvey.data.frame.list"))) {
     # one is an edsurvey.data.frame, the other an edsurvey.data.frame.list
-    if(inherits(e1, "edsurvey.data.frame.list")) {
-      return(notFunction(unlist(lapply(e1$datalist, function(x) { sameSurvey(x, e2) }))))
+    if (inherits(e1, "edsurvey.data.frame.list")) {
+      return(notFunction(unlist(lapply(e1$datalist, function(x) {
+        sameSurvey(x, e2)
+      }))))
     }
-    if(inherits(e2, "edsurvey.data.frame.list")) {
-      return(notFunction(unlist(lapply(e2$datalist, function(x) { sameSurvey(e1, x) }))))
+    if (inherits(e2, "edsurvey.data.frame.list")) {
+      return(notFunction(unlist(lapply(e2$datalist, function(x) {
+        sameSurvey(e1, x)
+      }))))
     }
   }
   return(FALSE)
@@ -686,26 +712,30 @@ equals.edsurvey.data <- function(e1, e2, notFunction) {
 
 #' @rdname edsurvey-class
 #' @export
-setMethod("%in%", signature(x = "edsurvey.data.frame"),
-          function(x, table) {
-            matchESDF(x, table)
-          })
+setMethod(
+  "%in%", signature(x = "edsurvey.data.frame"),
+  function(x, table) {
+    matchESDF(x, table)
+  }
+)
 
 #' @rdname edsurvey-class
 #' @export
-setMethod("%in%", signature(x = "edsurvey.data.frame.list"),
-          function(x, table) {
-            matchESDFL(x, table)
-          })
+setMethod(
+  "%in%", signature(x = "edsurvey.data.frame.list"),
+  function(x, table) {
+    matchESDFL(x, table)
+  }
+)
 
-matchESDF <- function(x, table, nomatch = NA_integer_, uncomparables=NULL) {
-  if(inherits(table, "edsurvey.data.frame")) {
+matchESDF <- function(x, table, nomatch = NA_integer_, uncomparables = NULL) {
+  if (inherits(table, "edsurvey.data.frame")) {
     sameSurvey(x, table)
   }
-  if(inherits(table, "edsurvey.data.frame.list")) {
+  if (inherits(table, "edsurvey.data.frame.list")) {
     dlist <- table$datalist
-    for(i in 1:length(dlist)) {
-      if(sameSurvey(x, dlist[[i]])) {
+    for (i in 1:length(dlist)) {
+      if (sameSurvey(x, dlist[[i]])) {
         return(TRUE)
       }
       return(FALSE)
@@ -715,19 +745,19 @@ matchESDF <- function(x, table, nomatch = NA_integer_, uncomparables=NULL) {
 }
 
 
-matchESDFL <- function(x, table, nomatch = NA_integer_, uncomparables=NULL) {
+matchESDFL <- function(x, table, nomatch = NA_integer_, uncomparables = NULL) {
   # x is an edsurvey.data.frame.list
   dlistx <- x$datalist
   res <- rep(FALSE, length(dlistx))
-  if(inherits(table, "edsurvey.data.frame")) {
-    for(j in 1:length(dlistx)) {
+  if (inherits(table, "edsurvey.data.frame")) {
+    for (j in 1:length(dlistx)) {
       res[j] <- sameSurvey(dlistx[[j]], table)
     }
   }
-  if(inherits(table, "edsurvey.data.frame.list")) {
+  if (inherits(table, "edsurvey.data.frame.list")) {
     dlist <- table$datalist
-    for(i in 1:length(dlist)) {
-      for(j in 1:length(dlistx)) {
+    for (i in 1:length(dlist)) {
+      for (j in 1:length(dlistx)) {
         res[j] <- res[j] || sameSurvey(dlistx[[j]], dlist[[i]])
       }
     }
