@@ -14,7 +14,7 @@
 #' @export
 showPlausibleValues <- function(data, verbose = FALSE) {
   if (inherits(data, c("edsurvey.data.frame.list"))) {
-    itterateESDFL(match.call(),data)
+    itterateESDFL(match.call(), data)
     return(invisible(NULL))
   }
   checkDataClass(data, c("edsurvey.data.frame", "light.edsurvey.data.frame", "edsurvey.data.frame.list"))
@@ -24,21 +24,24 @@ showPlausibleValues <- function(data, verbose = FALSE) {
   pvNames <- names(pvvars)
   txt <- paste0("There are ", length(pvNames), " subject scale(s) or subscale(s) in this edsurvey.data.frame:\n")
   eout(txt)
-  if(is.null(attributes(pvvars)$default))
-  attributes(pvvars)$default <- "" # should not resolve to a test
+  if (is.null(attributes(pvvars)$default)) {
+    attributes(pvvars)$default <- ""
+  } # should not resolve to a test
   if (length(pvNames) == 0) {
     return(invisible(NULL))
   }
   for (i in 1:length(pvNames)) {
     pvi <- pvvars[[i]]
-	pvn <- lapply(names(pvi)[grep("[Vv]arnames", names(pvi))], function(name) {
-	  length(pvi[[name]])
-	})
-	npv <- sum(unlist(pvn))
-    txt <- paste0("  ", sQuote(names(pvvars)[i]),
-               " subject scale or subscale with ",
-               npv, 
-               " plausible values")
+    pvn <- lapply(names(pvi)[grep("[Vv]arnames", names(pvi))], function(name) {
+      length(pvi[[name]])
+    })
+    npv <- sum(unlist(pvn))
+    txt <- paste0(
+      "  ", sQuote(names(pvvars)[i]),
+      " subject scale or subscale with ",
+      npv,
+      " plausible values"
+    )
     if (attributes(pvvars)$default == pvNames[i]) {
       # if there is a default plausible value, return with paste ' (the default)'
       txt <- paste0(txt, " (the default).")
@@ -46,15 +49,16 @@ showPlausibleValues <- function(data, verbose = FALSE) {
       txt <- paste0(txt, ".")
     } # End of if statment if attributes(data$pvvars)$default == pvNames[i]
     writeLines(strwrap(txt,
-                       width=getOption("width")*0.9,
-                       exdent=2))
+      width = getOption("width") * 0.9,
+      exdent = 2
+    ))
     if (verbose) {
       # if verbose = TRUE, return all plausible value details for each subject scale/subscale
       txt <- "The plausible value variables are: "
       pvi <- getPlausibleValue(pvNames[i], data)
       txt <- paste0(txt, pasteItems(paste0("'", pvi, "'")))
-      eout(txt, indent=2)
-    } # end of is statment: if verbrose 
+      eout(txt, indent = 2)
+    } # end of is statment: if verbrose
     cat("\n")
   } # End of loop for i in 1:length(pvNames)
 }
@@ -78,11 +82,11 @@ showPlausibleValues <- function(data, verbose = FALSE) {
 #' @export
 getPlausibleValue <- function(var, data) {
   if (inherits(data, c("edsurvey.data.frame.list"))) {
-    return(itterateESDFL(match.call(),data))
+    return(itterateESDFL(match.call(), data))
   }
   checkDataClass(data, c("edsurvey.data.frame", "light.edsurvey.data.frame", "edsurvey.data.frame.list"))
-  
-  if(any(!hasPlausibleValue(var, data))) {
+
+  if (any(!hasPlausibleValue(var, data))) {
     stop("The ", sQuote("var"), " argument level of ", dQuote(var), " does not have plausible values.")
   }
 
@@ -90,15 +94,15 @@ getPlausibleValue <- function(var, data) {
   pv <- getAttributes(data, "pvvars")
   # extract just the variable names (on the data) for the variables in question
   pvi <- lapply(var, function(vn) {
-    if(grepl("_linking", vn, fixed=TRUE)) {
-	  c(pv[[vn]]$estVarnames, pv[[vn]]$impVarnames, pv[[vn]]$sampVarnames)
+    if (grepl("_linking", vn, fixed = TRUE)) {
+      c(pv[[vn]]$estVarnames, pv[[vn]]$impVarnames, pv[[vn]]$sampVarnames)
     } else {
       pv[[vn]]$varnames
-	}
-  } )
-  
+    }
+  })
+
   # turn them into a single vector and return; return a NULL warning if any of the pvs are NULL (they shouldn't ever be though)
-  if(any(is.null(pvi))) {
+  if (any(is.null(pvi))) {
     surveyPaste <- getAttributes(data, "survey")
     yearPaste <- getAttributes(data, "year")
     warning(paste(surveyPaste, yearPaste, "returns a NULL plausible value."))
@@ -124,31 +128,31 @@ getPlausibleValue <- function(var, data) {
 #' @example \man\examples\updatePlausibleValue.R
 #' @export
 updatePlausibleValue <- function(oldVar, newVar, data) {
-  if(oldVar == newVar) {
+  if (oldVar == newVar) {
     return(data)
   }
   if (inherits(data, c("edsurvey.data.frame.list"))) {
-    return(itterateESDFL(match.call(),data))
+    return(itterateESDFL(match.call(), data))
   }
   checkDataClass(data, c("edsurvey.data.frame", "light.edsurvey.data.frame", "edsurvey.data.frame.list"))
-  
-  if(!hasPlausibleValue(oldVar, data)) {
-    stop(paste0("The argument ", sQuote("oldVar"), " with value ", sQuote(oldVar) ," is not a plausible value variable."))
+
+  if (!hasPlausibleValue(oldVar, data)) {
+    stop(paste0("The argument ", sQuote("oldVar"), " with value ", sQuote(oldVar), " is not a plausible value variable."))
   }
-  if(newVar %in% names(getAttributes(data, "pvvars"))) {
+  if (newVar %in% names(getAttributes(data, "pvvars"))) {
     stop(paste0("Plausible value variable name ", sQuote(newVar), " already in use. Try another name."))
-  } 
+  }
   if (inherits(data, c("edsurvey.data.frame"))) {
     # data is an edsurvey.data.frame, so plausible value is returned in data$pvvars[var]
     names(data$pvvars)[names(data$pvvars) == oldVar] <- newVar
-    if(attributes(data$pvvars)$default == oldVar) {
+    if (attributes(data$pvvars)$default == oldVar) {
       attributes(data$pvvars)$default <- newVar
     }
   } else {
     # data is a light.edsurvey.data.frame, so plausible value is returned in
     # attributes(data)$pvvars[var]
     names(attributes(data)$pvvars)[names(attributes(data)$pvvars) == oldVar] <- newVar
-    if(oldVar %in% attributes(attributes(data)$pvvars)$default) {
+    if (oldVar %in% attributes(attributes(data)$pvvars)$default) {
       attributes(attributes(data)$pvvars)$default <- newVar
     }
   }
@@ -176,7 +180,7 @@ updatePlausibleValue <- function(oldVar, newVar, data) {
 #' @export
 hasPlausibleValue <- function(var, data) {
   if (inherits(data, c("edsurvey.data.frame.list"))) {
-    return(itterateESDFL(match.call(),data))
+    return(itterateESDFL(match.call(), data))
   }
   checkDataClass(data, c("edsurvey.data.frame", "light.edsurvey.data.frame", "edsurvey.data.frame.list"))
 
