@@ -1,5 +1,5 @@
 \dontrun{
-pol <- readICILS("C:/ICILS/2013", countries = "pol", dataSet = "student")
+pol <- readICILS("~/ICILS/2013", countries = "pol", dataSet = "student")
 gg <- getData(pol, c("idstud", "cil", "is1g18b"))
 head(gg)
 edsurveyTable(cil ~ is1g18b, pol)
